@@ -4,16 +4,18 @@ package Perl::Dist::WiX::Fragment::Environment;
 # Perl::Dist::WiX::Fragment::Environment - Fragment & Component that contains
 #  <Environment> tags
 #
-# Copyright 2009 Curtis Jewell
+# Copyright 2009 - 2010 Curtis Jewell
 #
-# License is the same as perl. See Wix.pm for details.
+# License is the same as perl. See WiX.pm for details.
 #
 use 5.008001;
 use Moose;
-use WiX3::XML::Environment;
+require WiX3::XML::Environment;
+require WiX3::XML::Component;
+require WiX3::XML::DirectoryRef;
 
-our $VERSION = '1.100';
-$VERSION = eval $VERSION; ## no critic (ProhibitStringyEval)
+our $VERSION = '1.102';
+$VERSION =~ s/_//ms;
 
 extends 'WiX3::XML::Fragment';
 
